//---------------------------------------------------------------------------
// Copyright (C) 2000 Dallas Semiconductor Corporation, All Rights Reserved.
// 
// Permission is hereby granted, free of charge, to any person obtaining a 
// copy of this software and associated documentation files (the "Software"), 
// to deal in the Software without restriction, including without limitation 
// the rights to use, copy, modify, merge, publish, distribute, sublicense, 
// and/or sell copies of the Software, and to permit persons to whom the 
// Software is furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included 
// in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
// MERCHANTABILITY,  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
// IN NO EVENT SHALL DALLAS SEMICONDUCTOR BE LIABLE FOR ANY CLAIM, DAMAGES 
// OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
// ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
// OTHER DEALINGS IN THE SOFTWARE.
// 
// Except as contained in this notice, the name of Dallas Semiconductor 
// shall not be used except as stated in the Dallas Semiconductor 
// Branding Policy. 
//--------------------------------------------------------------------------
//
//  Starter.C - The main subroutine call that initializes all of the calls.


#include <PalmOS.h>
#include <PalmTypes.h>
#include <PalmCompatibility.h>
#include <stdio.h>
#include "StarterRsc.h"
#include "ownet.h"


// External Functions	
extern int  owAcquire(int,char *, char *);
extern int  owFirst(int,int,int);
extern int  owNext(int,int,int);
extern void owRelease(int,char *);
extern void owSerialNum(int,uchar *, int);
extern void msDelay(int);
extern void output_status(int, char *);
extern void ClearScreen(int);

// local funcitons
static Word StartApplication(void);
void PrintSerialNum(int,int);


DWord PilotMain(Word cmd, void *cmdPBP, Word launchflags)
{
   	Word error;
   
	char return_msg[128];
	int portnum = 0;
	int rslt,cnt;
	EventType event;

   	if(cmd == sysAppLaunchCmdNormalLaunch)
   	{
      	error = StartApplication();
      	if(error) return error;
    
   		if (!owAcquire(portnum,"0",return_msg))
   		{  
   			output_status(LV_ALWAYS,return_msg);
   			msDelay(5000);
      		return 0;
   		}
   		else
   		{
   			do
   			{
 	  			WinDrawChars((char *) "LIST OF BUTTONS",15,45,20);
      			cnt = 0;

      			// find the first device (all devices not just alarming)
      			rslt = owFirst(portnum, TRUE, FALSE);
            	
      			while (rslt)
      			{
         			// print the device number
         			cnt++;

         			// print the Serial Number of the device just found
         			PrintSerialNum(portnum, cnt-1);

         			// find the next device
         			rslt = owNext(portnum, TRUE, FALSE);
      			}
      			
      			WinDrawChars((char *) "PRESS TO EXIT",13,10,140);
      			
      			ClearScreen(4+cnt);
      			
      			EvtGetEvent(&event,1);
      		
      		} while(event.eType != penDownEvent);
	  	}

   	  	// release the 1-Wire Net	  
	  	owRelease(portnum, return_msg);

	}   
	     
    return 0;   
}

//---------------------------------------------------------------------
static Word StartApplication(void)
{
   FrmGotoForm(MainForm);  
   return 0;
}


//----------------------------------------------------------------------
//  Read and print the Serial Number.
//
void PrintSerialNum(int portnum, int cnt)
{
   uchar serial_num[8];
   char tempstr[32];   
   int i,len=0;

   owSerialNum(portnum,serial_num,TRUE);

   for (i=7; i>=0; i--)
   {
   		len += sprintf(&tempstr[len],"%02X", serial_num[i]);
   }
   len += sprintf(&tempstr[len]," ");

	WinDrawChars(tempstr,StrLen(tempstr),45,40+(cnt*10));
}



