//---------------------------------------------------------------------------
// Copyright (C) 2000 Dallas Semiconductor Corporation, All Rights Reserved.
// 
// Permission is hereby granted, free of charge, to any person obtaining a 
// copy of this software and associated documentation files (the "Software"), 
// to deal in the Software without restriction, including without limitation 
// the rights to use, copy, modify, merge, publish, distribute, sublicense, 
// and/or sell copies of the Software, and to permit persons to whom the 
// Software is furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included 
// in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
// MERCHANTABILITY,  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
// IN NO EVENT SHALL DALLAS SEMICONDUCTOR BE LIABLE FOR ANY CLAIM, DAMAGES 
// OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
// ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
// OTHER DEALINGS IN THE SOFTWARE.
// 
// Except as contained in this notice, the name of Dallas Semiconductor 
// shall not be used except as stated in the Dallas Semiconductor 
// Branding Policy. 
//--------------------------------------------------------------------------
//
//  Starter.C - The main subroutine call that initializes all of the calls.

#include <PalmOS.h>
#include <PalmTypes.h>
#include <PalmCompatibility.h>
#include "StarterRsc.h"
#include "ownet.h"
#include "thermo21.h"


// External Functions	
extern int  owAcquire(int,char *);
extern void owRelease(int);
extern void msDelay(int);
extern int FindDevices(int,uchar FamilySN[][8],int,int);
extern int ReadThermoStatus(int,uchar *,ThermoStateType *, FILE *);
extern void  InterpretStatus(MissionStatus *);
extern void MissionStatusToString(MissionStatus *,int,char *);
extern int  owSpeed(int,int);
extern void output_status(int,char *);
extern void reset_screen(void);

// local funcitons
static Word StartApplication(void);

// Local Variables
#define MAXDEVICES 	3
uchar family[MAXDEVICES][8];
ThermoStateType ThermoState;


DWord PilotMain(Word cmd, void *cmdPBP, Word launchflags)
{
   	Word error;
   
	int portnum = 0;
	int i,j,numdev=0;
	char str[558];
	int ConvertToF = TRUE;
	int notclear = TRUE;
	EventType event;
	FILE temp;
	

   	if(cmd == sysAppLaunchCmdNormalLaunch)
   	{
      	error = StartApplication();
      	if(error) 
      		return error;
      	    
   		if (!owAcquire(portnum,"0"))
   		{  
   			output_status(LV_ALWAYS,"Port was not Acquired.\n");
   			msDelay(5000);
      		return 0;
   		}
   		else
   		{
   			do
   			{
   			    owSpeed(portnum,MODE_NORMAL);
   				numdev = FindDevices(portnum,&family[0],THERMO_FAM,MAXDEVICES);
   			   	
   				if(numdev == 0)
   				{
   					if(notclear)
   					{
   						reset_screen();
   						notclear = FALSE;   					
   						
   						output_status(LV_ALWAYS,"Thermochron not present on 1-Wire\n");
   						output_status(LV_ALWAYS,"PRESS TO EXIT OR ADD DS1921\n");
   					}
   				}
   				else
   				{
   					notclear = TRUE;
   					
   					for(i=0;i<numdev;i++)
   					{
   						reset_screen();
   						for (j = 7; j >= 0; j--)
         					ThermoState.MissStat.serial_num[j] = family[i][j];

						if(ReadThermoStatus(portnum, &family[i][0], &ThermoState, &temp))
						{
							InterpretStatus(&ThermoState.MissStat);

							MissionStatusToString(&ThermoState.MissStat, ConvertToF, str);
							
							output_status(LV_ALWAYS,str);
						}   
						else 
							output_status(LV_ALWAYS,"Did not read\n");

						output_status(LV_ALWAYS,"PRESS TO CONTINUE\n");
						
						do
						{
							EvtGetEvent(&event,1);
						} while(event.eType != penDownEvent);					
						
					}	

				}
				
				EvtGetEvent(&event,1);
				
			} while(event.eType != penDownEvent);
			
		}
		
		// release the 1-Wire Net	  
	  	owRelease(portnum);
	  	output_status(LV_ALWAYS,"The port was released.\n");
	  	
	}   
	     
    return 0;   
}

//---------------------------------------------------------------------
static Word StartApplication(void)
{
   FrmGotoForm(MainForm);  
   return 0;
}



